pub struct AutoscalingRunnerSetTemplateSpecEphemeralContainersEnvValueFromFileKeyRef {
pub key: String,
pub optional: Option<bool>,
pub path: String,
pub volume_name: String,
}Expand description
FileKeyRef selects a key of the env file. Requires the EnvFiles feature gate to be enabled.
Fields
key: StringThe key within the env file. An invalid key will prevent the pod from starting. The keys defined within a source may consist of any printable ASCII characters except ‘=’. During Alpha stage of the EnvFiles feature gate, the key size is limited to 128 characters.
optional: Option<bool>Specify whether the file or its key must be defined. If the file or key does not exist, then the env var is not published. If optional is set to true and the specified key does not exist, the environment variable will not be set in the Pod’s containers.
If optional is set to false and the specified key does not exist, an error will be returned during Pod creation.
path: StringThe path within the volume from which to select the file. Must be relative and may not contain the ‘..’ path or start with ‘..’.
volume_name: StringThe name of the volume mount containing the env file.