pub struct AutoscalingRunnerSetTemplateSpecInitContainersEnvFromSecretRef {
pub name: Option<String>,
pub optional: Option<bool>,
}Expand description
The Secret to select from
Fields
name: Option<String>Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
optional: Option<bool>Specify whether the Secret must be defined