EphemeralRunnerSetEphemeralRunnerMetadata

Struct EphemeralRunnerSetEphemeralRunnerMetadata 

pub struct EphemeralRunnerSetEphemeralRunnerMetadata {
    pub annotations: Option<BTreeMap<String, String>>,
    pub labels: Option<BTreeMap<String, String>>,
}
EphemeralRunnerMetadata is the metadata to be applied to all ephemeral runners created by this set. If the EphemeralRunnerMetadata is updated, the update applies to new ephemeral runners created after the update, but does not apply to existing ephemeral runners.

Fields

annotations: Option<BTreeMap<String, String>>labels: Option<BTreeMap<String, String>>