pub struct AutoscalingRunnerSetTemplateSpecDnsConfig {
pub nameservers: Option<Vec<String>>,
pub options: Option<Vec<AutoscalingRunnerSetTemplateSpecDnsConfigOptions>>,
pub searches: Option<Vec<String>>,
}Expand description
Specifies the DNS parameters of a pod. Parameters specified here will be merged to the generated DNS configuration based on DNSPolicy.
Fields
nameservers: Option<Vec<String>>A list of DNS name server IP addresses. This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
options: Option<Vec<AutoscalingRunnerSetTemplateSpecDnsConfigOptions>>A list of DNS resolver options. This will be merged with the base options generated from DNSPolicy. Duplicated entries will be removed. Resolution options given in Options will override those that appear in the base DNSPolicy.
searches: Option<Vec<String>>A list of DNS search domains for host-name lookup. This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.